AudioFormat enum

Audio format for audio input/output.

Inheritance
Available extensions

Values

wav → const AudioFormat

WAV format.

const AudioFormat('wav')
mp3 → const AudioFormat

MP3 format.

const AudioFormat('mp3')
flac → const AudioFormat

FLAC format.

const AudioFormat('flac')
opus → const AudioFormat

Opus format.

const AudioFormat('opus')
pcm16 → const AudioFormat

PCM 16-bit format.

const AudioFormat('pcm16')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The JSON value for this format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String value) AudioFormat
Creates an AudioFormat from JSON.

Constants

values → const List<AudioFormat>
A constant List of the values in this enum, in order of their declaration.