ChatSessionChatkitConfiguration class

ChatKit feature configuration for a session.

Annotations
  • @immutable

Constructors

ChatSessionChatkitConfiguration({required ChatSessionAutomaticThreadTitling automaticThreadTitling, required ChatSessionFileUpload fileUpload, required ChatSessionHistory history})
Creates a ChatSessionChatkitConfiguration.
const
ChatSessionChatkitConfiguration.fromJson(Map<String, dynamic> json)
Creates a ChatSessionChatkitConfiguration from JSON.
factory

Properties

automaticThreadTitling ChatSessionAutomaticThreadTitling
Automatic thread titling preferences.
final
fileUpload ChatSessionFileUpload
Upload settings for the session.
final
hashCode int
The hash code for this object.
no setterinherited
history ChatSessionHistory
History retention configuration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited