CheckpointMetrics class

Training metrics for a checkpoint.

Annotations
  • @immutable

Constructors

CheckpointMetrics({int? step, double? trainLoss, double? trainMeanTokenAccuracy, double? validLoss, double? validMeanTokenAccuracy, double? fullValidLoss, double? fullValidMeanTokenAccuracy})
Creates a CheckpointMetrics.
const
CheckpointMetrics.fromJson(Map<String, dynamic> json)
Creates a CheckpointMetrics from JSON.
factory

Properties

fullValidLoss double?
Full validation loss.
final
fullValidMeanTokenAccuracy double?
Full validation mean token accuracy.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step int?
The step number.
final
trainLoss double?
Training loss.
final
trainMeanTokenAccuracy double?
Training mean token accuracy.
final
validLoss double?
Validation loss.
final
validMeanTokenAccuracy double?
Validation mean token accuracy.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override