CompactResponseRequest class

Request to compact response conversation state.

Annotations
  • @immutable

Constructors

CompactResponseRequest({required String model, ResponseInput? input, String? previousResponseId, String? instructions, String? promptCacheKey, PromptCacheRetention? promptCacheRetention, ServiceTier? serviceTier})
Creates a CompactResponseRequest.
const
CompactResponseRequest.fromJson(Map<String, dynamic> json)
Creates a CompactResponseRequest from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
input ResponseInput?
Optional input to compact. Can be plain text or item history.
final
instructions String?
Optional instructions to apply during compaction.
final
model String
The model to use for compaction.
final
previousResponseId String?
Optional previous response ID to compact from.
final
promptCacheKey String?
Optional prompt cache key.
final
promptCacheRetention PromptCacheRetention?
Optional prompt cache retention policy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceTier ServiceTier?
The service tier for request processing.
final

Methods

copyWith({String? model, Object? input = unsetCopyWithValue, Object? previousResponseId = unsetCopyWithValue, Object? instructions = unsetCopyWithValue, Object? promptCacheKey = unsetCopyWithValue, Object? promptCacheRetention = unsetCopyWithValue, Object? serviceTier = unsetCopyWithValue}) CompactResponseRequest
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override