CompleteUploadRequest class

A request to complete an upload.

Annotations
  • @immutable

Constructors

CompleteUploadRequest({required List<String> partIds, String? md5})
Creates a CompleteUploadRequest.
const
CompleteUploadRequest.fromJson(Map<String, dynamic> json)
Creates a CompleteUploadRequest from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
md5 String?
Optional MD5 checksum to verify the file.
final
partIds List<String>
The ordered list of part IDs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override