ContainerFileList class

A list of container files.

Annotations
  • @immutable

Constructors

ContainerFileList({required String object, required List<ContainerFile> data, String? firstId, String? lastId, required bool hasMore})
Creates a ContainerFileList.
const
ContainerFileList.fromJson(Map<String, dynamic> json)
Creates a ContainerFileList from JSON.
factory

Properties

data List<ContainerFile>
The list of container files.
final
firstId String?
The ID of the first file in the list, or null if empty.
final
hashCode int
The hash code for this object.
no setteroverride
hasMore bool
Whether there are more files available.
final
isEmpty bool
Whether the list is empty.
no setter
isNotEmpty bool
Whether the list is not empty.
no setter
lastId String?
The ID of the last file in the list, or null if empty.
final
length int
The number of files.
no setter
object String
The object type, which is always list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override