ContentPartAddedEvent class

Event emitted when a content part is added.

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ContentPartAddedEvent({required int outputIndex, required int contentIndex, required OutputContent part, String? itemId, int? sequenceNumber})
Creates a ContentPartAddedEvent.
const
ContentPartAddedEvent.fromJson(Map<String, dynamic> json)
Creates a ContentPartAddedEvent from JSON.
factory

Properties

contentIndex int
The index of the content part.
final
finalResponse Response?

Available on ResponseStreamEvent, provided by the ResponseStreamEventExtensions extension

Returns the final response if this is a completion event.
no setter
hashCode int
The hash code for this object.
no setteroverride
isFinal bool
Whether this event signals the end of the stream.
no setterinherited
itemId String?
The ID of the item containing this content part.
final
outputIndex int
The index of the output item.
final
part OutputContent
The added content part.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber int?
The sequence number for ordering events.
final
textDelta String?

Available on ResponseStreamEvent, provided by the ResponseStreamEventExtensions extension

Returns the text delta if this is a text delta event.
no setter
type String
The type of the event.
no setteroverride

Methods

copyWith({int? outputIndex, int? contentIndex, OutputContent? part, Object? itemId = unsetCopyWithValue, Object? sequenceNumber = unsetCopyWithValue}) ContentPartAddedEvent
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override