ConversationCodeInterpreterCallItem class

A code interpreter call item in a conversation.

Inheritance
Annotations
  • @immutable

Constructors

ConversationCodeInterpreterCallItem({required String id, String? code, String? language, List<Map<String, dynamic>>? outputs, ItemStatus? status})
Creates a ConversationCodeInterpreterCallItem.
const
ConversationCodeInterpreterCallItem.fromJson(Map<String, dynamic> json)
Creates a ConversationCodeInterpreterCallItem from JSON.
factory

Properties

code String?
The code being executed.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier.
final
language String?
The language of the code.
final
outputs List<Map<String, dynamic>>?
The outputs from execution.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ItemStatus?
Item status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override