ConversationFunctionCallItem class

A function call item in a conversation.

Inheritance
Annotations
  • @immutable

Constructors

ConversationFunctionCallItem({required String id, required String callId, required String name, required String arguments, ItemStatus? status})
Creates a ConversationFunctionCallItem.
const
ConversationFunctionCallItem.fromJson(Map<String, dynamic> json)
Creates a ConversationFunctionCallItem from JSON.
factory

Properties

arguments String
The function arguments as JSON string.
final
callId String
The call ID for this function call.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier.
final
name String
The function name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ItemStatus?
Item status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override