ConversationOutputTextContent class

Output text content in a conversation.

Inheritance
Annotations
  • @immutable

Constructors

ConversationOutputTextContent({required String text, List<Annotation>? annotations})
Creates a ConversationOutputTextContent.
const
ConversationOutputTextContent.fromJson(Map<String, dynamic> json)
Creates a ConversationOutputTextContent from JSON.
factory

Properties

annotations List<Annotation>?
Annotations for the text.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text content.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override