n property

  1. @JsonKey.new(includeIfNull: false)
int? get n
inherited

How many chat completion choices to generate for each input message. Note that you will be charged based on the number of generated tokens across all of the choices. Keep n as 1 to minimize costs.

Implementation

@JsonKey(name: 'max_completion_tokens', includeIfNull: false) int? get maxCompletionTokens;/// How many chat completion choices to generate for each input message. Note that you will be charged based on
/// the number of generated tokens across all of the choices. Keep `n` as `1` to minimize costs.
@JsonKey(includeIfNull: false) int? get n;