topLogprobs property

  1. @JsonKey.new(name: 'top_logprobs', includeIfNull: false)
int? get topLogprobs
inherited

An integer between 0 and 20 specifying the number of most likely tokens to return at each token position, each with an associated log probability. logprobs must be set to true if this parameter is used.

Implementation

@JsonKey(includeIfNull: false) bool? get logprobs;/// An integer between 0 and 20 specifying the number of most likely tokens to
/// return at each token position, each with an associated log probability.
/// `logprobs` must be set to `true` if this parameter is used.
@JsonKey(name: 'top_logprobs', includeIfNull: false) int? get topLogprobs;