DeleteVideoResponse class

The response from deleting a video.

Annotations
  • @immutable

Constructors

DeleteVideoResponse({required String id, required String object, required bool deleted})
Creates a DeleteVideoResponse.
const
DeleteVideoResponse.fromJson(Map<String, dynamic> json)
Creates a DeleteVideoResponse from JSON.
factory

Properties

deleted bool
Indicates that the video resource was deleted.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Identifier of the deleted video.
final
object String
The object type that signals the deletion response.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override