EvalDataSourceConfig class sealed

Configuration for the data source used in evaluations.

The data source config defines where evaluation data comes from and what schema it follows. There are two types of data sources:

Implementers
Annotations
  • @immutable

Constructors

EvalDataSourceConfig.fromJson(Map<String, dynamic> json)
Creates an EvalDataSourceConfig from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of data source configuration.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Map<String, dynamic>? itemSchema, bool? includeSampleSchema}) CustomDataSourceConfig
Creates a custom data source config.
logs({Map<String, dynamic>? schema, Map<String, dynamic>? metadata}) LogsDataSourceConfig
Creates a logs data source config.