FileSearchCallOutputItem class

A file search call output item.

Returned when the model uses the FileSearchTool.

Inheritance
Annotations
  • @immutable

Constructors

FileSearchCallOutputItem({required String id, List<String>? queries, List<Map<String, dynamic>>? results, ItemStatus? status})
Creates a FileSearchCallOutputItem.
const
FileSearchCallOutputItem.fromJson(Map<String, dynamic> json)
Creates a FileSearchCallOutputItem from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier.
final
queries List<String>?
The search queries performed.
final
results List<Map<String, dynamic>>?
The search results.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ItemStatus?
Item status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override