FineTuningError class

An error from fine-tuning.

Annotations
  • @immutable

Constructors

FineTuningError({String? code, String? message, String? param})
Creates a FineTuningError.
const
FineTuningError.fromJson(Map<String, dynamic> json)
Creates a FineTuningError from JSON.
factory

Properties

code String?
The error code.
final
hashCode int
The hash code for this object.
no setteroverride
message String?
The error message.
final
param String?
The parameter that caused the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override