FineTuningEventList class

A list of fine-tuning events.

Annotations
  • @immutable

Constructors

FineTuningEventList({required String object, required List<FineTuningEvent> data, required bool hasMore})
Creates a FineTuningEventList.
const
FineTuningEventList.fromJson(Map<String, dynamic> json)
Creates a FineTuningEventList from JSON.
factory

Properties

data List<FineTuningEvent>
The list of events.
final
hashCode int
The hash code for this object.
no setteroverride
hasMore bool
Whether there are more events.
final
object String
The object type (always "list").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override