FineTuningStatus enum
Fine-tuning job status values.
Values
- validatingFiles → const FineTuningStatus
-
Validating training files.
const FineTuningStatus._('validating_files') - queued → const FineTuningStatus
-
Job is queued.
const FineTuningStatus._('queued') - running → const FineTuningStatus
-
Job is running.
const FineTuningStatus._('running') - succeeded → const FineTuningStatus
-
Job succeeded.
const FineTuningStatus._('succeeded') - failed → const FineTuningStatus
-
Job failed.
const FineTuningStatus._('failed') - cancelled → const FineTuningStatus
-
Job was cancelled.
const FineTuningStatus._('cancelled')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts to JSON string.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FineTuningStatus> - A constant List of the values in this enum, in order of their declaration.