ImageContentPart class

An image URL content part.

Inheritance
Annotations
  • @immutable

Constructors

ImageContentPart({required String url, ImageDetail? detail, PromptCacheBreakpointConfig? promptCacheBreakpoint})
Creates an ImageContentPart.
const
ImageContentPart.fromJson(Map<String, dynamic> json)
Creates an ImageContentPart from JSON.
factory

Properties

detail ImageDetail?
The detail level for image processing.
final
hashCode int
The hash code for this object.
no setteroverride
promptCacheBreakpoint PromptCacheBreakpointConfig?
Cache breakpoint marker for this content block.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of this content part.
no setteroverride
url String
The URL of the image.
final

Methods

copyWith({String? url, Object? detail = unsetCopyWithValue, Object? promptCacheBreakpoint = unsetCopyWithValue}) ImageContentPart
Creates a copy with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override