ImageGenPartialImageEvent class

Partial image chunk emitted during streaming generation.

Inheritance
Annotations
  • @immutable

Constructors

ImageGenPartialImageEvent({required String b64Json, required int createdAt, required ImageSize size, required ImageQuality quality, required ImageBackground background, required ImageOutputFormat outputFormat, required int partialImageIndex})
Creates an ImageGenPartialImageEvent.
const
ImageGenPartialImageEvent.fromJson(Map<String, dynamic> json)
Creates an ImageGenPartialImageEvent from JSON.
factory

Properties

b64Json String
Base64-encoded partial image data.
final
background ImageBackground
Background. May be ImageBackground.unknown for out-of-spec values.
final
createdAt int
Unix timestamp when the event was created.
final
hashCode int
The hash code for this object.
no setteroverride
outputFormat ImageOutputFormat
Output format. May be ImageOutputFormat.unknown for out-of-spec values.
final
partialImageIndex int
0-based index of this partial image.
final
quality ImageQuality
Image quality. May be ImageQuality.unknown for out-of-spec values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ImageSize
Image size. May be ImageSize.unknown for out-of-spec values.
final
type String
The discriminator value.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the event.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override