ImageVariationRequest class

A request to create variations of an image.

Creates variations of an existing image.

Example

final request = ImageVariationRequest(
  image: originalImageBytes,
  imageFilename: 'original.png',
  n: 3,
);
Annotations
  • @immutable

Constructors

ImageVariationRequest({required Uint8List image, required String imageFilename, String? model, int? n, ImageResponseFormat? responseFormat, ImageSize? size, String? user})
Creates an ImageVariationRequest.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
image Uint8List
The image to use as the basis for variations.
final
imageFilename String
The filename of the image.
final
model String?
The model to use.
final
n int?
The number of images to generate.
final
responseFormat ImageResponseFormat?
The format for the generated images.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ImageSize?
The size of the generated images.
final
user String?
A unique identifier representing your end-user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override