InputFileContent class

File content via URL, file ID, or base64-encoded data.

Inheritance
Annotations
  • @immutable

Constructors

InputFileContent({String? fileUrl, String? fileId, String? fileData, String? filename, FileInputDetail? detail})
Creates an InputFileContent.
const
InputFileContent.data(String data, {required String mediaType, String? filename, FileInputDetail? detail})
Creates an InputFileContent from base64-encoded data.
const
InputFileContent.file(String id, {String? filename, FileInputDetail? detail})
Creates an InputFileContent from a file ID.
const
InputFileContent.fromJson(Map<String, dynamic> json)
Creates an InputFileContent from JSON.
factory
InputFileContent.url(String url, {String? filename, FileInputDetail? detail})
Creates an InputFileContent from a URL.
const

Properties

detail FileInputDetail?
Optional detail level for file processing.
final
fileData String?
The file data as a data URL (e.g., data:application/pdf;base64,<data>).
final
fileId String?
The file ID.
final
filename String?
The filename.
final
fileUrl String?
The file URL.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override