InputTextContent class
Text content for user, system, and developer messages.
Serializes with type: 'input_text'. For assistant messages, use
AssistantTextContent instead.
- Inheritance
-
- Object
- InputContent
- InputTextContent
- Annotations
-
- @immutable
Constructors
- InputTextContent(String text, {PromptCacheBreakpointConfig? promptCacheBreakpoint})
-
Creates an InputTextContent.
const
-
InputTextContent.fromJson(Map<
String, dynamic> json) -
Creates an InputTextContent from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- promptCacheBreakpoint → PromptCacheBreakpointConfig?
-
Cache breakpoint marker for this content block.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The text content.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override