ItemReference class

Reference to a previously created item.

Inheritance
Annotations
  • @immutable

Constructors

ItemReference({required String id, AgentTag? agent})
Creates an ItemReference.
const
ItemReference.fromJson(Map<String, dynamic> json)
Creates an ItemReference from JSON.
factory

Properties

agent AgentTag?
The agent that produced this item.
final
hashCode int
The hash code for this object.
no setteroverride
id String
The ID of the referenced item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override