JsonlRunDataSource class

JSONL file-based data source for evaluation runs.

Inheritance
Annotations
  • @immutable

Constructors

JsonlRunDataSource({required JsonlSource source})
Creates a JsonlRunDataSource.
const
JsonlRunDataSource.fromJson(Map<String, dynamic> json)
Creates a JsonlRunDataSource from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source JsonlSource
The source of the JSONL data.
final
type String
The type of run data source.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override