LocalShellCallOutputResultItem class

A local shell call output result item.

Inheritance
Annotations
  • @immutable

Constructors

LocalShellCallOutputResultItem({required String id, AgentTag? agent, required String output, String? callId, ItemStatus? status})
Creates a LocalShellCallOutputResultItem.
const
LocalShellCallOutputResultItem.fromJson(Map<String, dynamic> json)
Creates a LocalShellCallOutputResultItem from JSON.
factory

Properties

agent AgentTag?
The agent that produced this item.
final
callId String?
The local shell call ID.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier.
final
output String
The serialized local shell output payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ItemStatus?
The status of the local shell call output.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override