MessageContentImageFile constructor

const MessageContentImageFile({
  1. @JsonKey.new(name: 'file_id') required String fileId,
  2. @Default.new(MessageContentImageDetail.auto) MessageContentImageDetail detail,
})

Factory constructor for MessageContentImageFile

Implementation

const factory MessageContentImageFile({
  /// The [File](https://platform.openai.com/docs/api-reference/files) ID of the image in the message content. Set `purpose="vision"` when uploading the File if you need to later display the file content.
  @JsonKey(name: 'file_id') required String fileId,

  /// Specifies the detail level of the image if specified by the user. `low` uses fewer tokens, you can opt in to high resolution using `high`.
  @Default(MessageContentImageDetail.auto) MessageContentImageDetail detail,
}) = _MessageContentImageFile;