MessagePhase enum

The phase of a message in a response.

Inheritance
Available extensions

Values

unknown → const MessagePhase

Unknown phase (fallback for unrecognized values).

const MessagePhase('unknown')
commentary → const MessagePhase

Commentary phase (intermediate thinking).

const MessagePhase('commentary')
finalAnswer → const MessagePhase

Final answer phase.

const MessagePhase('final_answer')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The JSON value for this phase.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Converts to JSON value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MessagePhase>
A constant List of the values in this enum, in order of their declaration.