ModerationErrorBody class

An error produced while attempting moderation for a request input or output.

Inheritance
Annotations
  • @immutable

Constructors

ModerationErrorBody({required String code, required String message})
Creates a ModerationErrorBody.
const
ModerationErrorBody.fromJson(Map<String, dynamic> json)
Creates a ModerationErrorBody from JSON.
factory

Properties

code String
The error code.
final
hashCode int
The hash code for this object.
no setteroverride
message String
The error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The discriminator type for this outcome.
no setteroverride

Methods

copyWith({String? code, String? message}) ModerationErrorBody
Creates a copy with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override