ModerationInputItem class sealed

A single item in a multi-modal moderation input.

Either a ModerationInputItemText or a ModerationInputItemImageUrl.

Implementers

Constructors

ModerationInputItem.fromJson(Map<String, dynamic> json)
Creates a ModerationInputItem from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

imageUrl(String url) ModerationInputItem
Creates an image URL input item.
text(String text) ModerationInputItem
Creates a text input item.