ModerationInputItemImageUrl class

An image URL input item for multi-modal moderation.

Contains either a URL or a base64 data URL for the image.

Implemented types
Annotations
  • @immutable

Constructors

ModerationInputItemImageUrl({required String url})
Creates a ModerationInputItemImageUrl.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
Either a URL of the image or the base64 encoded image data.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override