ModerationInputItemText class

A text input item for multi-modal moderation.

Implemented types
Annotations
  • @immutable

Constructors

ModerationInputItemText(String text)
Creates a ModerationInputItemText.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text to classify.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override