ModerationInputMultiModal class

Multi-modal input for moderation (text and/or images).

Use with omni-moderation models like omni-moderation-latest.

Implemented types
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
items List<ModerationInputItem>
The list of multi-modal input items.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override