OutputTextAnnotationAddedEvent class

Event emitted when a text annotation is added.

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

OutputTextAnnotationAddedEvent({required int outputIndex, required int contentIndex, required int annotationIndex, required Annotation annotation, String? itemId, int? sequenceNumber})
Creates an OutputTextAnnotationAddedEvent.
const
OutputTextAnnotationAddedEvent.fromJson(Map<String, dynamic> json)
Creates an OutputTextAnnotationAddedEvent from JSON.
factory

Properties

annotation Annotation
The annotation that was added.
final
annotationIndex int
The index of the annotation.
final
contentIndex int
The index of the content part.
final
finalResponse Response?

Available on ResponseStreamEvent, provided by the ResponseStreamEventExtensions extension

Returns the final response if this is a completion event.
no setter
hashCode int
The hash code for this object.
no setteroverride
isFinal bool
Whether this event signals the end of the stream.
no setterinherited
itemId String?
The ID of the item containing this annotation.
final
outputIndex int
The index of the output item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber int?
The sequence number for ordering events.
final
textDelta String?

Available on ResponseStreamEvent, provided by the ResponseStreamEventExtensions extension

Returns the text delta if this is a text delta event.
no setter
type String
The type of the event.
no setteroverride

Methods

copyWith({int? outputIndex, int? contentIndex, int? annotationIndex, Annotation? annotation, Object? itemId = unsetCopyWithValue, Object? sequenceNumber = unsetCopyWithValue}) OutputTextAnnotationAddedEvent
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override