ReasoningMode class sealed

Controls the reasoning execution mode for the request.

When returned on a response, this is the effective execution mode.

Known modes are available as variants:

The set of supported modes may expand over time; use CustomReasoningMode (ReasoningMode.custom(...)) for any value not yet modeled as a known mode.

Example

final standard = ReasoningMode.standard();
final custom = ReasoningMode.custom('turbo');
Implementers
Annotations
  • @immutable

Constructors

ReasoningMode.custom(String value)
A custom reasoning execution mode with the given value.
const
factory
ReasoningMode.fromJson(String json)
Creates a ReasoningMode from a JSON value.
factory
ReasoningMode.pro()
The pro reasoning execution mode.
const
factory
ReasoningMode.standard()
The standard reasoning execution mode.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw string value for this reasoning mode.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Converts to JSON value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited