ResponseAudioTranscriptDeltaEvent class

Event emitted when audio transcript is generated (delta).

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ResponseAudioTranscriptDeltaEvent({required String delta, int? sequenceNumber, AgentTag? agent})
Creates a ResponseAudioTranscriptDeltaEvent.
const
ResponseAudioTranscriptDeltaEvent.fromJson(Map<String, dynamic> json)
Creates a ResponseAudioTranscriptDeltaEvent from JSON.
factory

Properties

agent AgentTag?
The agent that owns this multi-agent streaming event.
final
delta String
The transcript delta.
final
finalResponse Response?

Available on ResponseStreamEvent, provided by the ResponseStreamEventExtensions extension

Returns the final response if this is a completion event.
no setter
hashCode int
The hash code for this object.
no setteroverride
isFinal bool
Whether this event signals the end of the stream.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber int?
The sequence number for ordering events.
final
textDelta String?

Available on ResponseStreamEvent, provided by the ResponseStreamEventExtensions extension

Returns the text delta if this is a text delta event.
no setter
type String
The type of the event.
no setteroverride

Methods

copyWith({String? delta, Object? sequenceNumber = unsetCopyWithValue, Object? agent = unsetCopyWithValue}) ResponseAudioTranscriptDeltaEvent
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override