ResponsesFileSource class

Responses source from a file.

Inheritance
Annotations
  • @immutable

Constructors

ResponsesFileSource({required String fileId})
Creates a ResponsesFileSource.
const
ResponsesFileSource.fromJson(Map<String, dynamic> json)
Creates a ResponsesFileSource from JSON.
factory

Properties

fileId String
The file ID.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of source.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override