SkillList class

Paginated list of Skill resources.

Annotations
  • @immutable

Constructors

SkillList({required String object, required List<Skill> data, String? firstId, String? lastId, required bool hasMore})
Creates a SkillList.
const
SkillList.fromJson(Map<String, dynamic> json)
Creates a SkillList from JSON.
factory

Properties

data List<Skill>
Items in the current page.
final
firstId String?
First item ID in this page.
final
hashCode int
The hash code for this object.
no setteroverride
hasMore bool
Whether there are more results.
final
lastId String?
Last item ID in this page.
final
object String
Object type, always list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override