SkillVersion class

A skill version resource.

Annotations
  • @immutable

Constructors

SkillVersion({required String object, required String id, required String skillId, required String version, required int createdAt, required String name, required String description})
Creates a SkillVersion.
const
SkillVersion.fromJson(Map<String, dynamic> json)
Creates a SkillVersion from JSON.
factory

Properties

createdAt int
Unix timestamp for creation.
final
description String
Version description.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Unique version identifier.
final
name String
Version name.
final
object String
Object type, always skill.version.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillId String
Parent skill identifier.
final
version String
Version value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override