ThreadItemList class

A list of thread items.

Annotations
  • @immutable

Constructors

ThreadItemList({required String object, required List<ThreadItem> data, String? firstId, String? lastId, required bool hasMore})
Creates a ThreadItemList.
const
ThreadItemList.fromJson(Map<String, dynamic> json)
Creates a ThreadItemList from JSON.
factory

Properties

data List<ThreadItem>
The list of thread items.
final
firstId String?
The ID of the first item in the list.
final
hashCode int
The hash code for this object.
no setteroverride
hasMore bool
Whether there are more items available.
final
isEmpty bool
Whether the list is empty.
no setter
isNotEmpty bool
Whether the list is not empty.
no setter
lastId String?
The ID of the last item in the list.
final
length int
The number of items.
no setter
object String
The object type, which is always list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override