TranscriptTextDoneEvent class

Emitted when a streaming transcription is complete.

Contains the complete transcription text.

Inheritance
Annotations
  • @immutable

Constructors

TranscriptTextDoneEvent({required String text, List<TranscriptionLanguage>? languages, List<TranscriptionLogprob>? logprobs, TranscriptTextUsageTokens? usage})
Creates a TranscriptTextDoneEvent.
const
TranscriptTextDoneEvent.fromJson(Map<String, dynamic> json)
Creates a TranscriptTextDoneEvent from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
languages List<TranscriptionLanguage>?
The languages detected in the audio. Returned by gpt-transcribe. An empty list indicates that no language could be reliably detected.
final
logprobs List<TranscriptionLogprob>?
The log probabilities of the individual tokens in the transcription. Only included when the request's include list contains logprobs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text that was transcribed.
final
type String
The discriminator value.
no setteroverride
usage TranscriptTextUsageTokens?
Token usage statistics for the request.
final

Methods

copyWith({String? text, Object? languages = unsetCopyWithValue, Object? logprobs = unsetCopyWithValue, Object? usage = unsetCopyWithValue}) TranscriptTextDoneEvent
Creates a copy with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the event.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override