logprobs property
The log probabilities of the individual tokens in the transcription.
Only included when the request's include list contains logprobs.
Implementation
final List<TranscriptionLogprob>? logprobs;
The log probabilities of the individual tokens in the transcription.
Only included when the request's include list contains logprobs.
final List<TranscriptionLogprob>? logprobs;