TranslationResponse class

A translation response.

Contains the translated English text from the audio input.

Annotations
  • @immutable

Constructors

TranslationResponse({required String text})
Creates a TranslationResponse.
const
TranslationResponse.fromJson(Map<String, dynamic> json)
Creates a TranslationResponse from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The translated English text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override