UpdateEvalRequest class

Request to update an existing evaluation.

Annotations
  • @immutable

Constructors

UpdateEvalRequest({String? name, Map<String, dynamic>? metadata})
Creates an UpdateEvalRequest.
const
UpdateEvalRequest.fromJson(Map<String, dynamic> json)
Creates an UpdateEvalRequest from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
metadata Map<String, dynamic>?
New metadata for the evaluation.
final
name String?
New name for the evaluation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override