UserPartsContent class

Multiple content parts for a user message.

Used for multimodal messages that include images or audio.

Inheritance
Annotations
  • @immutable

Constructors

UserPartsContent(List<ContentPart> parts)
Creates content with multiple parts.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
parts List<ContentPart>
The content parts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
Converts to JSON format expected by the API.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override