WebSearchOptions class abstract

This tool searches the web for relevant results to use in a response.

Available extensions
Annotations
  • @freezed

Constructors

WebSearchOptions({@JsonKey.new(name: 'user_location', includeIfNull: false) WebSearchOptionsUserLocation? userLocation, @JsonKey.new(name: 'search_context_size') @Default.new(WebSearchContextSize.medium) WebSearchContextSize searchContextSize})
Factory constructor for WebSearchOptions
const
factory
WebSearchOptions.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $WebSearchOptionsCopyWith<WebSearchOptions>
Create a copy of WebSearchOptions with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchContextSize WebSearchContextSize
High level guidance for the amount of context window space to use for the search. One of low, medium, or high. medium is the default.
no setterinherited
userLocation WebSearchOptionsUserLocation?
Approximate location parameters for the search.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_WebSearchOptions value)) → TResult

Available on WebSearchOptions, provided by the WebSearchOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_WebSearchOptions value)?) → TResult?

Available on WebSearchOptions, provided by the WebSearchOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_WebSearchOptions value)?, {required TResult orElse()}) → TResult

Available on WebSearchOptions, provided by the WebSearchOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(WebSearchOptionsUserLocation? userLocation, WebSearchContextSize searchContextSize)?, {required TResult orElse()}) → TResult

Available on WebSearchOptions, provided by the WebSearchOptionsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this WebSearchOptions to a JSON map.
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values
when<TResult extends Object?>(TResult $default(WebSearchOptionsUserLocation? userLocation, WebSearchContextSize searchContextSize)) → TResult

Available on WebSearchOptions, provided by the WebSearchOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(WebSearchOptionsUserLocation? userLocation, WebSearchContextSize searchContextSize)?) → TResult?

Available on WebSearchOptions, provided by the WebSearchOptionsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema