CreateVectorStoreRequest class

A request to create a vector store.

Annotations
  • @immutable

Constructors

CreateVectorStoreRequest({List<String>? fileIds, String? name, ExpirationPolicy? expiresAfter, ChunkingStrategy? chunkingStrategy, Map<String, String>? metadata})
Creates a CreateVectorStoreRequest.
const
CreateVectorStoreRequest.fromJson(Map<String, dynamic> json)
Creates a CreateVectorStoreRequest from JSON.
factory

Properties

chunkingStrategy ChunkingStrategy?
The chunking strategy.
final
expiresAfter ExpirationPolicy?
The expiration policy.
final
fileIds List<String>?
File IDs to add to the vector store.
final
hashCode int
The hash code for this object.
no setteroverride
metadata Map<String, String>?
Custom metadata.
final
name String?
The name of the vector store.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override