ModifyThreadRequest class
A request to modify a thread.
- Annotations
-
- @immutable
Constructors
-
ModifyThreadRequest({ToolResources? toolResources, Map<
String, String> ? metadata}) -
Creates a ModifyThreadRequest.
const
-
ModifyThreadRequest.fromJson(Map<
String, dynamic> json) -
Creates a ModifyThreadRequest from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
metadata
→ Map<
String, String> ? -
Custom metadata.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolResources → ToolResources?
-
Tool resources for the thread.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override