ModifyVectorStoreRequest class
A request to modify a vector store.
- Annotations
-
- @immutable
Constructors
-
ModifyVectorStoreRequest({String? name, ExpirationPolicy? expiresAfter, Map<
String, String> ? metadata}) -
Creates a ModifyVectorStoreRequest.
const
-
ModifyVectorStoreRequest.fromJson(Map<
String, dynamic> json) -
Creates a ModifyVectorStoreRequest from JSON.
factory
Properties
- expiresAfter → ExpirationPolicy?
-
The expiration policy.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
metadata
→ Map<
String, String> ? -
Custom metadata.
final
- name → String?
-
The name of the vector store.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override