VectorStoreFileList class

A list of vector store files.

Annotations
  • @immutable

Constructors

VectorStoreFileList({required String object, required List<VectorStoreFile> data, String? firstId, String? lastId, required bool hasMore})
Creates a VectorStoreFileList.
const
VectorStoreFileList.fromJson(Map<String, dynamic> json)
Creates a VectorStoreFileList from JSON.
factory

Properties

data List<VectorStoreFile>
The list of files.
final
firstId String?
The ID of the first file.
final
hashCode int
The hash code for this object.
no setteroverride
hasMore bool
Whether there are more files.
final
lastId String?
The ID of the last file.
final
object String
The object type (always "list").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override