clientSecret property
The ephemeral client secret for WebSocket authentication.
This field is present when the session is created via the HTTP endpoint, but may be null when the session is returned as part of another response.
Implementation
final ClientSecret? clientSecret;