RealtimeTranslationClientSecretCreateRequest class

Request for creating a translation client secret.

Calls POST /realtime/translations/client_secrets.

Example

final response = await client.realtimeSessions.translations
    .createClientSecret(
  RealtimeTranslationClientSecretCreateRequest(
    session: RealtimeTranslationSessionCreateRequest(
      model: 'gpt-realtime-translate',
      audio: RealtimeTranslationSessionAudio(
        output: RealtimeTranslationSessionAudioOutput(language: 'es'),
      ),
    ),
  ),
);
Annotations
  • @immutable

Properties

expiresAfter ExpiresAfter?
Optional expiration configuration.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session RealtimeTranslationSessionCreateRequest
The translation session configuration.
final

Methods

copyWith({RealtimeTranslationSessionCreateRequest? session, Object? expiresAfter = unsetCopyWithValue}) RealtimeTranslationClientSecretCreateRequest
Returns a copy with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override