RealtimeTranslationErrorEvent class

Returned when an error occurs in a translation session.

Inheritance
Annotations
  • @immutable

Constructors

RealtimeTranslationErrorEvent({required String eventId, required RealtimeTranslationError error})
Creates a RealtimeTranslationErrorEvent.
const
RealtimeTranslationErrorEvent.fromJson(Map<String, dynamic> json)
Creates from JSON.
factory

Properties

error RealtimeTranslationError
Error payload.
final
eventId String
The server-generated event id.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The discriminator value.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override