RealtimeTranslationInputAudioBufferAppendEvent class

Append base64-encoded audio bytes to the translation input buffer.

WebSocket translation sessions accept base64-encoded 24 kHz PCM16 mono little-endian raw audio bytes. Note: this base64 is the raw audio bytes from the client, not a request-factory data URL — the OpenAI-specific data:<mediaType>;base64,<data> rule does not apply.

Inheritance
Annotations
  • @immutable

Properties

audio String
Base64-encoded 24 kHz PCM16 mono raw audio bytes.
final
eventId String?
Optional client-generated event id.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The discriminator value.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override