RealtimeTranslationOutputTranscriptDeltaEvent class

Translated transcript delta.

Inheritance
Annotations
  • @immutable

Constructors

RealtimeTranslationOutputTranscriptDeltaEvent({required String eventId, required String delta, int? elapsedMs})
Creates a RealtimeTranslationOutputTranscriptDeltaEvent.
const
RealtimeTranslationOutputTranscriptDeltaEvent.fromJson(Map<String, dynamic> json)
Creates from JSON.
factory

Properties

delta String
Append-only translated transcript fragment.
final
elapsedMs int?
Optional alignment-frame timing in 200 ms increments.
final
eventId String
The server-generated event id.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The discriminator value.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override