RealtimeTranslationSession class

A Realtime translation session.

Translation sessions continuously translate input audio into the configured output language.

Annotations
  • @immutable

Constructors

RealtimeTranslationSession({required String id, required String type, required int expiresAt, required String model, required RealtimeTranslationSessionAudio audio})
Creates a RealtimeTranslationSession.
const
RealtimeTranslationSession.fromJson(Map<String, dynamic> json)
Creates from JSON.
factory

Properties

audio RealtimeTranslationSessionAudio
Audio configuration.
final
expiresAt int
Expiration timestamp (Unix epoch seconds).
final
hashCode int
The hash code for this object.
no setteroverride
id String
Unique session identifier (sess_…).
final
model String
The translation model used for this session.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The session type. Always 'translation'.
final

Methods

copyWith({String? id, String? type, int? expiresAt, String? model, RealtimeTranslationSessionAudio? audio}) RealtimeTranslationSession
Returns a copy with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override