RealtimeTranslationSessionAudioOutput class

Output audio configuration for a translation session.

Annotations
  • @immutable

Constructors

RealtimeTranslationSessionAudioOutput({String? language})
Creates a RealtimeTranslationSessionAudioOutput.
const
RealtimeTranslationSessionAudioOutput.fromJson(Map<String, dynamic> json)
Creates from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
language String?
Target language for translated output audio and transcript deltas.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? language = unsetCopyWithValue}) RealtimeTranslationSessionAudioOutput
Returns a copy with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override