session property
Translation session fields to update. The session type and model are
set at creation and cannot be changed via session.update.
Implementation
final RealtimeTranslationSessionUpdateRequest session;
Translation session fields to update. The session type and model are
set at creation and cannot be changed via session.update.
final RealtimeTranslationSessionUpdateRequest session;