RealtimeTranslationSessionUpdatedEvent class

Returned when a translation session is updated.

Inheritance
Annotations
  • @immutable

Constructors

RealtimeTranslationSessionUpdatedEvent({required String eventId, required RealtimeTranslationSession session})
Creates a RealtimeTranslationSessionUpdatedEvent.
const
RealtimeTranslationSessionUpdatedEvent.fromJson(Map<String, dynamic> json)
Creates from JSON.
factory

Properties

eventId String
The server-generated event id.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session RealtimeTranslationSession
The updated translation session.
final
type String
The discriminator value.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override