ResponseFunctionCallArgumentsDeltaEvent class

Response function call arguments delta event.

Implemented types
Annotations
  • @immutable

Constructors

ResponseFunctionCallArgumentsDeltaEvent({required String eventId, required String responseId, required String itemId, required int outputIndex, required String callId, required String delta})
Creates a ResponseFunctionCallArgumentsDeltaEvent.
const
ResponseFunctionCallArgumentsDeltaEvent.fromJson(Map<String, dynamic> json)
Creates a ResponseFunctionCallArgumentsDeltaEvent from JSON.
factory

Properties

callId String
The function call ID.
final
delta String
The arguments delta.
final
eventId String
The event ID.
final
hashCode int
The hash code for this object.
no setteroverride
itemId String
The item ID.
final
outputIndex int
The output index.
final
responseId String
The response ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The event type.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override