ResponseFunctionCallArgumentsDoneEvent class

Response function call arguments done event.

Implemented types
Annotations
  • @immutable

Constructors

ResponseFunctionCallArgumentsDoneEvent({required String eventId, required String responseId, required String itemId, required int outputIndex, required String callId, required String arguments})
Creates a ResponseFunctionCallArgumentsDoneEvent.
const
ResponseFunctionCallArgumentsDoneEvent.fromJson(Map<String, dynamic> json)
Creates a ResponseFunctionCallArgumentsDoneEvent from JSON.
factory

Properties

arguments String
The complete arguments.
final
callId String
The function call ID.
final
eventId String
The event ID.
final
hashCode int
The hash code for this object.
no setteroverride
itemId String
The item ID.
final
outputIndex int
The output index.
final
responseId String
The response ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The event type.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override