SessionUpdateConfig class

Configuration for updating a session.

Annotations
  • @immutable

Constructors

SessionUpdateConfig({List<String>? modalities, String? instructions, RealtimeVoice? voice, RealtimeAudioFormat? inputAudioFormat, RealtimeAudioFormat? outputAudioFormat, InputAudioTranscription? inputAudioTranscription, TurnDetection? turnDetection, List<RealtimeTool>? tools, RealtimeToolChoice? toolChoice, double? temperature, InfOrInt? maxResponseOutputTokens})
Creates a SessionUpdateConfig.
const
SessionUpdateConfig.fromJson(Map<String, dynamic> json)
Creates a SessionUpdateConfig from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
inputAudioFormat RealtimeAudioFormat?
Input audio format.
final
inputAudioTranscription InputAudioTranscription?
Input audio transcription config.
final
instructions String?
System instructions.
final
maxResponseOutputTokens InfOrInt?
Maximum output tokens ("inf" or a specific integer).
final
modalities List<String>?
The modalities to enable.
final
outputAudioFormat RealtimeAudioFormat?
Output audio format.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature double?
Sampling temperature.
final
toolChoice RealtimeToolChoice?
Tool choice setting.
final
tools List<RealtimeTool>?
Available tools.
final
turnDetection TurnDetection?
Turn detection config.
final
voice RealtimeVoice?
The voice to use.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override