TracingConfiguration class

Granular tracing configuration.

Inheritance
Annotations
  • @immutable

Constructors

TracingConfiguration({String? groupId, Map<String, dynamic>? metadata, String? workflowName})
Creates a TracingConfiguration.
const
TracingConfiguration.fromJson(Map<String, dynamic> json)
Creates from JSON.
factory

Properties

groupId String?
Optional group identifier for filtering in the Traces Dashboard.
final
hashCode int
The hash code for this object.
no setteroverride
metadata Map<String, dynamic>?
Optional arbitrary metadata.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workflowName String?
Optional workflow name.
final

Methods

copyWith({Object? groupId = unsetCopyWithValue, Object? metadata = unsetCopyWithValue, Object? workflowName = unsetCopyWithValue}) TracingConfiguration
Returns a copy of this TracingConfiguration with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON. Returns either the string "auto" or a Map.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override