ContextManagement class
Context management configuration for responses requests.
- Annotations
-
- @immutable
Constructors
- ContextManagement({required String type, int? compactThreshold})
-
Creates a ContextManagement.
const
- ContextManagement.compaction({int? compactThreshold})
-
Creates a compaction configuration entry.
const
-
ContextManagement.fromJson(Map<
String, dynamic> json) -
Creates a ContextManagement from JSON.
factory
Properties
- compactThreshold → int?
-
Token threshold at which compaction should be triggered.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Entry type. Currently
compaction.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override