ConversationFunctionCallOutputItem class
A function call output item in a conversation.
- Inheritance
-
- Object
- ConversationItem
- ConversationFunctionCallOutputItem
- Annotations
-
- @immutable
Constructors
- ConversationFunctionCallOutputItem({required String id, required String callId, required Object output, FunctionCallStatus? status})
-
Creates a ConversationFunctionCallOutputItem.
const
-
ConversationFunctionCallOutputItem.fromJson(Map<
String, dynamic> json) -
Creates a ConversationFunctionCallOutputItem from JSON.
factory
Properties
- callId → String
-
The call ID this output corresponds to.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Unique identifier.
final
- output → Object
-
The output content (can be string or list).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → FunctionCallStatus?
-
The status of the function call.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override