functionCall property
- @JsonKey.new(name: 'function_call', includeIfNull: false)
inherited
Deprecated in favor of tool_choice.
Controls which (if any) function is called by the model.
none means the model will not call a function and instead generates a
message.
auto means the model can pick between generating a message or calling a
function.
Specifying a particular function via {"name": "my_function"} forces the
model to call that function.
none is the default when no functions are present. auto is the default
if functions are present.
Implementation
@JsonKey(includeIfNull: false) String? get user;/// Deprecated in favor of `tool_choice`.
///
/// Controls which (if any) function is called by the model.
///
/// `none` means the model will not call a function and instead generates a
/// message.
///
/// `auto` means the model can pick between generating a message or calling a
/// function.
///
/// Specifying a particular function via `{"name": "my_function"}` forces the
/// model to call that function.
///
/// `none` is the default when no functions are present. `auto` is the default
/// if functions are present.
@_ChatCompletionFunctionCallConverter()@JsonKey(name: 'function_call', includeIfNull: false) ChatCompletionFunctionCall? get functionCall;