CustomToolCallOutputItem class
A custom tool call output item.
- Inheritance
-
- Object
- OutputItem
- CustomToolCallOutputItem
- Annotations
-
- @immutable
Constructors
- CustomToolCallOutputItem({required String id, AgentTag? agent, required String callId, required FunctionCallOutput output, FunctionCallOutputStatus? status, String? createdBy, ToolCallCaller? caller})
-
Creates a CustomToolCallOutputItem.
const
-
CustomToolCallOutputItem.fromJson(Map<
String, dynamic> json) -
Creates a CustomToolCallOutputItem from JSON.
factory
Properties
- agent → AgentTag?
-
The agent that produced this item.
final
- caller → ToolCallCaller?
-
The execution context that produced the tool call this output responds
to.
final
- callId → String
-
The call ID for this custom tool call output.
final
- createdBy → String?
-
The identifier of the actor that created the item.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Unique identifier.
final
- output → FunctionCallOutput
-
The output from the custom tool call.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → FunctionCallOutputStatus?
-
The status of the item.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override