EvalDataSourceConfig class sealed
Configuration for the data source used in evaluations.
The data source config defines where evaluation data comes from and what schema it follows. There are two types of data sources:
- CustomDataSourceConfig - Custom data with a user-defined schema
- LogsDataSourceConfig - Data from stored logs
- Implementers
- Annotations
-
- @immutable
Constructors
-
EvalDataSourceConfig.fromJson(Map<
String, dynamic> json) -
Creates an EvalDataSourceConfig from JSON.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited