FileSearchRankingOptions class
Ranking options for file search.
- Annotations
-
- @immutable
Constructors
- FileSearchRankingOptions({String? ranker, double? scoreThreshold})
-
Creates a FileSearchRankingOptions.
const
-
FileSearchRankingOptions.fromJson(Map<
String, dynamic> json) -
Creates a FileSearchRankingOptions from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- ranker → String?
-
The ranker to use for scoring results.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scoreThreshold → double?
-
The score threshold for filtering results.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override