FileUploadParam class
File upload parameter.
- Annotations
-
- @immutable
Constructors
- FileUploadParam({required bool enabled, int? maxFileSize, int? maxFiles})
-
Creates a FileUploadParam.
const
Properties
- enabled → bool
-
Whether file uploads are enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxFiles → int?
-
Maximum number of files allowed.
final
- maxFileSize → int?
-
Maximum file size in megabytes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited