FineTuningEvent class
A fine-tuning job event.
- Annotations
-
- @immutable
Constructors
- FineTuningEvent({required String id, required String object, required int createdAt, required String level, required String message})
-
Creates a FineTuningEvent.
const
-
FineTuningEvent.fromJson(Map<
String, dynamic> json) -
Creates a FineTuningEvent from JSON.
factory
Properties
- createdAt → int
-
The Unix timestamp.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
The event ID.
final
- level → String
-
The log level ("info", "warn", "error").
final
- message → String
-
The event message.
final
- object → String
-
The object type (always "fine_tuning.job.event").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override