FunctionCallDelta class
A function call delta in a streaming chunk.
- Annotations
-
- @immutable
Constructors
- FunctionCallDelta({String? name, String? arguments})
-
Creates a FunctionCallDelta.
const
-
FunctionCallDelta.fromJson(Map<
String, dynamic> json) -
Creates a FunctionCallDelta from JSON.
factory
Properties
- arguments → String?
-
The partial arguments string for this chunk.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String?
-
The name of the function (only in the first chunk for this function).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override