FunctionCallOutputItemResponse class
A function call output item in the response.
- Inheritance
-
- Object
- OutputItem
- FunctionCallOutputItemResponse
- Annotations
-
- @immutable
Constructors
- FunctionCallOutputItemResponse({required String id, AgentTag? agent, required String callId, required String name, required String arguments, ItemStatus? status, String? namespace, String? createdBy, ToolCallCaller? caller})
-
Creates a FunctionCallOutputItemResponse.
const
-
FunctionCallOutputItemResponse.fromJson(Map<
String, dynamic> json) -
Creates a FunctionCallOutputItemResponse from JSON.
factory
Properties
- agent → AgentTag?
-
The agent that produced this item.
final
- arguments → String
-
The function arguments as JSON string.
final
-
argumentsMap
→ Map<
String, dynamic> -
The arguments parsed as a JSON map.
no setter
- caller → ToolCallCaller?
-
The execution context that produced this tool call.
final
- callId → String
-
The call ID for this function call.
final
- createdBy → String?
-
The identifier of the actor that created the item.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Unique identifier.
final
- name → String
-
The function name.
final
- namespace → String?
-
The namespace this function call belongs to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ItemStatus?
-
Item status.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFunctionCallItem(
) → FunctionCallItem - Converts to a FunctionCallItem for use as input.
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override