Hyperparameters class
Hyperparameters for a fine-tuning job.
- Annotations
-
- @immutable
Constructors
- Hyperparameters({AutoOrInt? nEpochs, AutoOrInt? batchSize, AutoOrDouble? learningRateMultiplier})
-
Creates a Hyperparameters.
const
-
Hyperparameters.fromJson(Map<
String, dynamic> json) -
Creates a Hyperparameters from JSON.
factory
Properties
- batchSize → AutoOrInt?
-
The batch size ("auto" or a specific integer).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- learningRateMultiplier → AutoOrDouble?
-
The learning rate multiplier ("auto" or a specific double).
final
- nEpochs → AutoOrInt?
-
The number of epochs ("auto" or a specific integer).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override