InfOrIntValue class
Represents a specific integer value.
Constructors
- InfOrIntValue(int value)
-
Creates an InfOrIntValue.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isInf → bool
-
Whether this is infinity.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The integer value.
final
- valueOrNull → int?
-
Gets the integer value, or null if infinity.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override