InputImageOutputContent class
Image content echoed as output.
Mirrors InputImageContent but appears in output contexts such as the
beta multi-agent protocol's agent message content union
(OpenAI-Beta: responses_multi_agent=v1).
- Inheritance
-
- Object
- OutputContent
- InputImageOutputContent
- Annotations
-
- @immutable
Constructors
- InputImageOutputContent({String? imageUrl, String? fileId, ImageDetail? detail, PromptCacheBreakpointConfig? promptCacheBreakpoint})
-
Creates an InputImageOutputContent.
const
-
InputImageOutputContent.fromJson(Map<
String, dynamic> json) -
Creates an InputImageOutputContent from JSON.
factory
Properties
- detail → ImageDetail?
-
Optional detail level.
final
- fileId → String?
-
The file ID (for uploaded files).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- imageUrl → String?
-
The image URL.
final
- promptCacheBreakpoint → PromptCacheBreakpointConfig?
-
Cache breakpoint marker for this content block.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override