JsonSchemaFormat class
JSON schema response format.
- Inheritance
-
- Object
- TextFormat
- JsonSchemaFormat
- Annotations
-
- @immutable
Constructors
-
JsonSchemaFormat({required String name, String? description, required Map<
String, dynamic> schema, bool? strict}) -
Creates a JsonSchemaFormat.
const
-
JsonSchemaFormat.fromJson(Map<
String, dynamic> json) -
Creates a JsonSchemaFormat from JSON.
factory
Properties
- description → String?
-
Optional description of the schema.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
The name of the schema.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schema
→ Map<
String, dynamic> -
The JSON Schema.
final
- strict → bool?
-
Whether to enforce strict schema adherence.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override