LocalShellCallOutputItem class
A local shell call output item.
- Inheritance
-
- Object
- OutputItem
- LocalShellCallOutputItem
- Annotations
-
- @immutable
Constructors
- LocalShellCallOutputItem({required String id, required String callId, required LocalShellExecAction action, required ItemStatus status})
-
Creates a LocalShellCallOutputItem.
const
-
LocalShellCallOutputItem.fromJson(Map<
String, dynamic> json) -
Creates a LocalShellCallOutputItem from JSON.
factory
Properties
- action → LocalShellExecAction
-
Typed action payload to execute locally.
final
- callId → String
-
The local shell call ID.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Unique identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ItemStatus
-
Item status.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override