MessageRole enum
The role of a message in a conversation.
Values
- unknown → const MessageRole
-
Unknown role (fallback for unrecognized values).
const MessageRole('unknown') - user → const MessageRole
-
User message.
const MessageRole('user') - system → const MessageRole
-
System message.
const MessageRole('system') - developer → const MessageRole
-
Developer message.
const MessageRole('developer') - assistant → const MessageRole
-
Assistant message.
const MessageRole('assistant') - critic → const MessageRole
-
A critic role (used in certain evaluation contexts).
const MessageRole('critic') - discriminator → const MessageRole
-
A discriminator role (used in certain evaluation contexts).
const MessageRole('discriminator') - tool → const MessageRole
-
Tool message.
const MessageRole('tool')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The JSON value for this role.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts to JSON value.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MessageRole> - A constant List of the values in this enum, in order of their declaration.