MultiAgentCallOutputResultItem class
The output of a multi-agent action call, as an output item.
This belongs to the beta multi-agent protocol
(OpenAI-Beta: responses_multi_agent=v1). Mirrors the
BetaMultiAgentCallOutput schema.
- Inheritance
-
- Object
- OutputItem
- MultiAgentCallOutputResultItem
- Annotations
-
- @immutable
Constructors
-
MultiAgentCallOutputResultItem({required String id, AgentTag? agent, required String callId, required MultiAgentAction action, required List<
OutputTextContent> output}) -
Creates a MultiAgentCallOutputResultItem.
const
-
MultiAgentCallOutputResultItem.fromJson(Map<
String, dynamic> json) -
Creates a MultiAgentCallOutputResultItem from JSON.
factory
Properties
- action → MultiAgentAction
-
The multi-agent action that produced this result.
final
- agent → AgentTag?
-
The agent that produced this item.
final
- callId → String
-
The unique ID of the multi-agent call.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
The unique ID of the multi-agent call output item.
final
-
output
→ List<
OutputTextContent> -
Text output returned by the multi-agent action.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override