ProgramOutputResultItem class
The result of a programmatic tool calling execution, as an output item.
Mirrors the ProgramOutput schema.
- Inheritance
-
- Object
- OutputItem
- ProgramOutputResultItem
- Annotations
-
- @immutable
Constructors
- ProgramOutputResultItem({required String id, AgentTag? agent, required String callId, required String result, required ProgramOutputStatus status})
-
Creates a ProgramOutputResultItem.
const
-
ProgramOutputResultItem.fromJson(Map<
String, dynamic> json) -
Creates a ProgramOutputResultItem from JSON.
factory
Properties
- agent → AgentTag?
-
The agent that produced this item.
final
- callId → String
-
The call ID of the program item.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
The unique ID of the program output item.
final
- result → String
-
The result produced by the program item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ProgramOutputStatus
-
The terminal status of the program output item.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override