ResponseFileSearchCallCompletedEvent class
Event emitted when a file search call is completed.
- Inheritance
-
- Object
- ResponseStreamEvent
- ResponseFileSearchCallCompletedEvent
- Available extensions
- Annotations
-
- @immutable
Constructors
- ResponseFileSearchCallCompletedEvent({required String itemId, required int outputIndex, int? sequenceNumber})
-
Creates a ResponseFileSearchCallCompletedEvent.
const
-
ResponseFileSearchCallCompletedEvent.fromJson(Map<
String, dynamic> json) -
Creates a ResponseFileSearchCallCompletedEvent from JSON.
factory
Properties
- finalResponse → Response?
-
Available on ResponseStreamEvent, provided by the ResponseStreamEventExtensions extension
Returns the final response if this is a completion event.no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- isFinal → bool
-
Whether this event signals the end of the stream.
no setterinherited
- itemId → String
-
The ID of the file search call item.
final
- outputIndex → int
-
The index of the output item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequenceNumber → int?
-
The sequence number for ordering events.
final
- textDelta → String?
-
Available on ResponseStreamEvent, provided by the ResponseStreamEventExtensions extension
Returns the text delta if this is a text delta event.no setter - type → String
-
The type of the event.
no setteroverride
Methods
-
copyWith(
{String? itemId, int? outputIndex, Object? sequenceNumber = unsetCopyWithValue}) → ResponseFileSearchCallCompletedEvent - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override