ResponseInjectError class
The error describing why an injected input was rejected.
This belongs to the beta multi-agent WebSocket protocol
(OpenAI-Beta: responses_multi_agent=v1).
- Annotations
-
- @immutable
Constructors
- ResponseInjectError({required ResponseInjectErrorCode code, required String message})
-
Creates a ResponseInjectError.
const
-
ResponseInjectError.fromJson(Map<
String, dynamic> json) -
Creates a ResponseInjectError from JSON.
factory
Properties
- code → ResponseInjectErrorCode
-
The error code.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String
-
A human-readable message describing the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ResponseInjectErrorCode? code, String? message}) → ResponseInjectError - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override