ScrollAction class
A scroll action at specific coordinates.
- Inheritance
-
- Object
- ComputerAction
- ScrollAction
- Annotations
-
- @immutable
Constructors
-
ScrollAction({required int x, required int y, required int scrollX, required int scrollY, List<
String> ? keys}) -
Creates a ScrollAction.
const
-
ScrollAction.fromJson(Map<
String, dynamic> json) -
Creates a ScrollAction from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
keys
→ List<
String> ? -
The keys being held while performing the action.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollX → int
-
The horizontal scroll amount.
final
- scrollY → int
-
The vertical scroll amount.
final
- x → int
-
The x coordinate.
final
- y → int
-
The y coordinate.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override