StreamException class
Exception thrown when streaming fails.
This can occur due to connection issues during streaming, malformed SSE data, or unexpected stream termination.
- Inheritance
-
- Object
- OpenAIException
- StreamException
- Annotations
-
- @immutable
Constructors
- StreamException({required String message, String? partialData, Object? cause})
-
Creates a new StreamException.
const
Properties
- cause → Object?
-
The underlying cause of this exception, if any.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable description of the error.
finalinherited
- partialData → String?
-
Any partial data received before the error occurred.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited